clear
set matsize 5000
set memory 150m
set more off
/* ************************************************************************************************************************** */
/* ************************************************************************************************************************** */
/* Holger Lutz Kern and Jens Hainmueller. "Electoral Balancing, Divided Government, and Midterm Loss in German Elections"	*/
/* Forthcoming 2006, Journal of Legislative Studies													*/
/* Do File 1: Replication Tables 1-3                                                                                          */
/* Version 1.5  11/11/2005                                                                                                    */
/* using data file: "midtermloss.dta"                                                                                         */
/* Instructions: Please copy the dataset to your STATA working directory and run the do file                                  */
/* ************************************************************************************************************************** */
/* This do file runs all recodings from the raw data and replicates all tables presented in our article.                      */
/* Log files labeled recodings, table1.log, table2.log, etc. are also created in your STATA working directory.                */
/* Thank you for your interest in our research! For questions please email hlk23@cornell.edu                                  */ 
/* ************************************************************************************************************************** */
/* ************************************************************************************************************************** */

log using recodings.log, replace
/* ************************************************************************************************************************** */
/* Recodings: Set up of dataset for analysis */
use "midtermloss.dta", clear
encode stpar_id, gen(STPAR_ID)
tsset STPAR_ID year

/* Set up: Covariates */
/* Log Differencing */
/* State Level Covars */
sort stpar_id year
gen     c_stue_t    =ln(stue)          -ln(stue[_n-1])     if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_stue_t    =ln(stue[_n-1])    -ln(stue[_n-2])     if stpar_id==stpar_id[_n-1] & lagdummy==1
gen     c_stgdpcap_t=ln(stgdpcap)      -ln(stgdpcap[_n-1]) if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_stgdpcap_t=ln(stgdpcap[_n-1])-ln(stgdpcap[_n-2]) if stpar_id==stpar_id[_n-1] & lagdummy==1
gen     c_stexpcap_t=ln(stexpcap)      -ln(stexpcap[_n-1]) if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_stexpcap_t=ln(stexpcap[_n-1])-ln(stexpcap[_n-2]) if stpar_id==stpar_id[_n-1] & lagdummy==1
/* Federal Level Covars */
gen     c_feinfl_t    =ln(feinfl)          -ln(feinfl[_n-1])     if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_feinfl_t    =ln(feinfl[_n-1])    -ln(feinfl[_n-2])     if stpar_id==stpar_id[_n-1] & lagdummy==1
gen     c_fegdpcap_t  =ln(fegdpcap)        -ln(fegdpcap[_n-1])   if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_fegdpcap_t  =ln(fegdpcap[_n-1])  -ln(fegdpcap[_n-2])   if stpar_id==stpar_id[_n-1] & lagdummy==1
gen     c_feue_t      =sqrt(feue)          -sqrt(feue[_n-1])     if stpar_id==stpar_id[_n-1] & lagdummy==0
replace c_feue_t      =sqrt(feue[_n-1])    -sqrt(feue[_n-2])     if stpar_id==stpar_id[_n-1] & lagdummy==1

/* Set up: Interaction Terms: State Incumbency X State and Federal Covariates*/
gen c_stincXc_stue_t      =   stinc*c_stue_t
gen c_stincXc_stgdpcap_t  =   stinc*c_stgdpcap_t
gen c_stincXc_stexpcap_t  =   stinc*c_stexpcap_t
gen c_stincXc_feinfl_t    =   stinc*c_feinfl_t
gen c_stincXc_fegdpcap_t  =   stinc*c_fegdpcap_t
gen c_stincXc_fedue_t     =   stinc*c_feue_t

/* *************************************************************************************************************************** */
log close


log using "table1.log", replace
*************************************************************************************************************************** */
/* Table 1                                                                                                                     */
/* The Midterm Effect in German State Eections                                                                                 */

/* Set up: Covariates Matrix Basline model */
/* Federal Incumbency */
gen xxfeinc=feinc
/* State Incumbency */
gen xxstinc=stinc
/* Bundesrats Majority Interaction Terms */
gen feincXbrdummy1=brdummy1*feinc
/* Rise and Decline */
gen xxstparvote_t=stparvote_t
/* Turnout */
gen xxstelecturnout=stelecturnout


/* Estimations */
/* Colum 1: The Incumbency Effect 1949-2003 All Parties (the constrained Incumbency Effect */
xi: reg stparvotech xx*                         i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
/* Colum 2: The Incumbency Effect and the BR majority 1949-2003 All Parties (the unconstrained Incumbency Effect) */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* Colum 3: The Incumbency Effect and the BR majority 1949-2003 CDU SPD FDP GREEN */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no<5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* Colum 4: The Incumbency Effect and the BR majority 1949-2003 CDU SPD FDP */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no<4, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* Colum 5: The Incumbency Effect and the BR majority 1949-2003 CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name  if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ************************************************************************************************************************* */
log close

log using "table2.log", replace
/* ************************************************************************************************************************ */
/* Table 2: Different Time Frames                                       *************************************************** */
/* Colum 1: The Incumbency Effect and the BR majority 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & year<=1989, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* Colum 2: The Incumbency Effect and the BR majority 1949-2003 CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & year<=1989, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1


/* Colum 3: The Incumbency Effect and the BR majority 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id   if east==0 & year>=1971 & par_no~=5 , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* Colum 4: The Incumbency Effect and the BR majority 1949-2003 CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1971 & par_no<3 , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ************************************************************************************************************************* */
log close



log using "table3.log", replace
/* ************************************************************************************************************************ */
/* Table 3: Different Specifications     *************************************************** */

/* ROW 1 is simply the estimates from Table 1 colums 2 and 5 */

/* ROWS 2 and 3 dislpay max and min BR interactions effects                             */
/* when iterativley re-estimating the model omitting one state at a time.               */
/* Estimates for all combinations are run in the code below table 3 (jacknife_a and _b) */
/* Here in table 3 we just repliacte the max and min effects we found                   */

/* ROW  2: ONE STATE OMITTED MAX BR INTERACTION EFFEKT 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=240, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  2: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=140, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  3: ONE STATE OMITTED MIN BR INTERACTION EFFEKT 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=150, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  3: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=150, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  4: Adding log diff. change in state gdp per cap & state expendtiure per cap 1949-2003 All Parties */
gen cc_stgdpcap_t=c_stgdpcap_t
gen cc_stexpcap_t=c_stexpcap_t
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  4: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  5: Interacted with state incumbency 1949-2003 All Parties */
/* Expand Covariates Matrix **** */
gen cc_stincXc_stgdpcap_t=c_stincXc_stgdpcap_t
gen cc_stincXc_stexpcap_t=c_stincXc_stexpcap_t
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  5: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  6: Adding additionaly log diff. change in federal inflationm, unemployent and & growth 1949-2003 All Parties */
gen cc_feinfl_t  =c_feinfl_t
gen cc_fegdpcap_t=c_fegdpcap_t
gen cc_feue_t    =c_feue_t
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  6: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  7: All interacted with incumbency 1949-2003 All Parties */
gen cc_stincXc_feinfl_t  =c_stincXc_feinfl_t
gen cc_stincXc_fegdpcap_t=c_stincXc_fegdpcap_t
gen cc_stincXc_fedue_t   =c_stincXc_fedue_t
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  7: 1949-2003 CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  8: Adding East Laender without covars 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  8: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  9: Adding East Laender all covars 1949-2003 All Parties */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  9: 1949-2003 CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  10: state elections under Grand Coalition exluded no covars 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=150 & year~=1967 & year~=1968 & year~=1969 , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  10: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=150 & year~=1967 & year~=1968 & year~=1969  , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  11: state elections under Grand Coalition exluded all  covars 1949-2003 All Parties */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=150 & year~=1967 & year~=1968 & year~=1969 , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  11: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=150 & year~=1967 & year~=1968 & year~=1969  , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  12: weighted by state population no covars 1949-2003 All Parties */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 [aw=stpop], cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  12: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name     if east==0 & year>=1949 & par_no<3 [aw=stpop],  cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  13: weighted by state population all covars 1949-2003 All Parties */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.stpar_id       if east==0 & year>=1949 & par_no~=5 [aw=stpop], cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  13: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 i.year i.st_name      if east==0 & year>=1949 & par_no<3 [aw=stpop],  cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  14: Party-State&Year interactions no covars 1949-2003 All Parties */
encode stpar_id, gen(stpar_ID)
gen stparyear=stpar_ID + year
tab stparyear, gen(styy) nof
encode st_name, gen(stname)
gen stateyear=stname+ year
tab stateyear, gen(stzz) nof
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 styy* i.year i.stpar_id     if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  13: CDU SPD */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 styy* i.year i.st_name  if east==0 & year>=1949 & par_no<3, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* *** */
/* ROW  14: Party-State&Year interactions all covars 1949-2003 All Parties */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 styy* i.year i.stpar_id if east==0 & year>=1949 & par_no~=5, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
/* ROW  14: CDU SPD */
xi: reg stparvotech xx* cc* feincXbrdummy1 brdummy1 stzz* i.year i.st_name  if east==0 & year>=1949 & par_no<3 , cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
test xxfeinc feincXbrdummy1
drop styy*
/* ************************************************************************************************************************************** */
log close


log using "jacknife_a.log", replace
/* ************************************************************************************************************************ */
/* Table 3ab Jacknife Estimations                                       *************************************************** */
/* Jackknife (Omitting one State at a time): Estimations for  All Parties samples 1949-2003 */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=100, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=110, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=120, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=140, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=150, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=160, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=180, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=190, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=200, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=210, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.stpar_id if east==0 & year>=1949 & par_no~=5 & st_no~=240, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
log close

log using "jacknife_b.log", replace
/* Jackknife (Omitting one State at a time): Estimations for  CDU SPD sample 1949-2003 */
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=100, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=110, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=120, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=140, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=150, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=160, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=180, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=190, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=200, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=210, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
xi: reg stparvotech xx* feincXbrdummy1 brdummy1 i.year i.st_name if east==0 & year>=1949 & par_no<3 & st_no~=240, cl(stpar_id)
lincom xxfeinc+feincXbrdummy1
/* ************************************************************************************************************************* */
log close
