clear
set matsize 5000
set memory 150m
set more off
/* ************************************************************************************************************************** */
/* ************************************************************************************************************************** */
/* Holger Lutz Kern and Jens Hainmueller. "Electoral Balancing, Divided Government, and Midterm Loss in German Elections"	*/
/* Forthcoming 2006, Journal of Legislative Studies													*/
/* Do File 2: Produces fig1.dta, i.e. the dataset for figure 1 to be read into R								*/
/* Version 1.2 11/11/2005                                                                                                     */
/* using data files: "midtermloss.dta"															*/
/* Instructions: Please copy the dataset to your STATA working directory and run the do file                                  */
/* Thank you for your interest in our research! For questions please email hlk23@cornell.edu                            	*/
/* ************************************************************************************************************************** */
/* ************************************************************************************************************************** */

/* Recodings: Set up of dataset */
use "midtermloss.dta", clear
encode stpar_id, gen(STPAR_ID)
tsset STPAR_ID year

/* Set up: Election Period Dummies T1-4 */
gen T1=0
gen T2=0
gen T3=0
gen T4=0
replace T1=1 if interval<=365
replace T1=. if stparvote==. | interval==.
replace T2=1 if interval>=366 & interval<=730
replace T2=. if stparvote==. | interval==.
replace T3=1 if interval>=731 & interval<=1095
replace T3=. if stparvote==. | interval==.
replace T4=1 if interval>=1096 & interval<=1460
replace T4=. if stparvote==. | interval==.

gen     electionyear=1 if T1==1
replace electionyear=2 if T2==1
replace electionyear=3 if T3==1
replace electionyear=4 if T4==1

drop     if  east==1
drop     if  stparvotech==.
drop     if  feinc==. | brdummy1==. 
drop     if  par_no==5

/* In fig 1 we include Grand Colaition Years */
/* one can also drop them using (see text)   */
/* drop     if year==1966 | year==1967       */

gen      ID=1 if  feinc==1 &  brdummy1==0
replace  ID=2 if  feinc==1 &  brdummy1==1

label define ID 1 "Divided Government" 2 "Unified Government"
label values ID ID

save "fig1.dta", replace